==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/no.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Administrere Lightbox Gallary parametere");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "leder Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Stort bilde Width");
define('MANAGE_GALLERY_FULL_HEIGHT', "Stort bilde Høyde");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniatyrbildebredde");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniatyrbildehøyde");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Bevar Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Vis Titler");
define('MANAGE_GALLERY_DISABLE_SORT', "Deaktiver Sorter");
define('MANAGE_GALLERY_DELETE_IMAGE', "Slett bilde");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Lagre sorteringsrekkefølge");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klikk &quot;Oppdater&quot; for å publisere <br /> opplastede bilder.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Alle bilder er blitt endret størrelse og innstillinger har blitt lagret.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Det oppstod en feil å endre størrelse på bildene eller lagre innstillinger.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Ditt bilde (r) har blitt lastet opp.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Det var en feil under opplasting bilde (r).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Filen du prøver å laste opp er ikke et bilde.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Filen du prøver å laste opp er for stor.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Tittelen er lagret.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Er du sikker på at du vil slette bilde");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Bildet er slettet.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Det var en feil ved sletting av bildet.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Lagrer parametere og endre størrelsen på bilder, vennligst vent ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Laster opp, vennligst vent ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Sorteringsrekkefølgen er ikke blitt lagret. Ønsker du å lagre sorteringsrekkefølge?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Bildet sorteringsrekkefølge er lagret.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Det oppstod en feil ved lagring av bildet sort.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/no.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Administrere Lightbox Gallary parametere");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "leder Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Stort bilde Width");
define('MANAGE_GALLERY_FULL_HEIGHT', "Stort bilde Høyde");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniatyrbildebredde");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniatyrbildehøyde");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Bevar Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Vis Titler");
define('MANAGE_GALLERY_DISABLE_SORT', "Deaktiver Sorter");
define('MANAGE_GALLERY_DELETE_IMAGE', "Slett bilde");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Lagre sorteringsrekkefølge");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klikk &quot;Oppdater&quot; for å publisere <br /> opplastede bilder.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Alle bilder er blitt endret størrelse og innstillinger har blitt lagret.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Det oppstod en feil å endre størrelse på bildene eller lagre innstillinger.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Ditt bilde (r) har blitt lastet opp.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Det var en feil under opplasting bilde (r).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Filen du prøver å laste opp er ikke et bilde.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Filen du prøver å laste opp er for stor.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Tittelen er lagret.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Er du sikker på at du vil slette bilde");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Bildet er slettet.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Det var en feil ved sletting av bildet.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Lagrer parametere og endre størrelsen på bilder, vennligst vent ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Laster opp, vennligst vent ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Sorteringsrekkefølgen er ikke blitt lagret. Ønsker du å lagre sorteringsrekkefølge?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Bildet sorteringsrekkefølge er lagret.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Det oppstod en feil ved lagring av bildet sort.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Filen du prøver å laste opp er større enn &#39;upload_max_filesize&#39; eller &#39;post_max_size&#39; PHP-innstillingene. Kontakt systemadministratoren for å øke disse grensene.");
?>
